@@ -9,6 +9,10 @@ class CFn:
 
     count_jsonb_keys: Final[str] = 'count_jsonb_keys'
 
+    http_status_data: Final[str] = 'http_status_data'
+    http_status_error: Final[str] = 'http_status_error'
+    http_status_error_code_only: Final[str] = 'http_status_error_code_only'
+
     id_2_bigint: Final[str] = 'id_2_bigint'
     id_2_int: Final[str] = 'id_2_int'
     if_null_2_empty_bigint_array: Final[str] = 'if_null_2_empty_bigint_array'
